@@ -39,7 +39,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGBookmarkPluginDockWidget(SKGDocument* iDocument);
+    explicit SKGBookmarkPluginDockWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
