@@ -27,6 +27,7 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
 
 /**
  * This plugin factory.
@@ -37,8 +38,9 @@ K_PLUGIN_FACTORY(SKGDashboardPluginFactory, registerPlugin<SKGDashboardPlugin>()
  */
 K_EXPORT_PLUGIN(SKGDashboardPluginFactory("skg_dashboard", "skg_dashboard"))
 
-SKGDashboardPlugin::SKGDashboardPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGDashboardPlugin::SKGDashboardPlugin(QObject* iParent, const QVariantList& iArg) : SKGInterfacePlugin(iParent)
 {
+    Q_UNUSED(iArg);
     SKGTRACEIN(10, "SKGDashboardPlugin::SKGDashboardPlugin");
 }
 
