@@ -26,12 +26,12 @@
 #include "skginterfaceplugin.h"
 #include "skgservices.h"
 #include "skgzoomselector.h"
+#include "skgflowlayout.h"
 
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <kmenu.h>
 #include <KService>
-#include <Plasma/DataEngine>
 
 #include <QDomDocument>
 #include <QSpacerItem>
@@ -65,7 +65,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
 
         //Build menu
         if (m_addMenu) {
-            const KPluginInfo::List skglist = Plasma::Applet::listAppletInfo("", "skrooge");
+            const KPluginInfo::List skglist = SKGMainPanel::getMainPanel()->getPlasmaApplets();
             foreach(const KPluginInfo & info, skglist) {
                 //Create menu
                 QAction* act = m_addMenu->addAction(info.name());
@@ -132,7 +132,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
 
         //Time to show floating panel
         m_timer.setSingleShot(true);
-        connect(&m_timer, SIGNAL(timeout()), this, SLOT(onShowFloatingPanel()));
+        connect(&m_timer, SIGNAL(timeout()), this, SLOT(onShowFloatingPanel()), Qt::QueuedConnection);
 
         //Build menu
         if (m_addMenu) {
