@@ -39,6 +39,7 @@
 #include <knewpassworddialog.h>
 #include <kpassworddialog.h>
 #include <kwallet.h>
+#include <kgenericfactory.h>
 
 #include <QtGui/QWidget>
 #include <QFile>
@@ -501,9 +502,9 @@ void SKGFilePlugin::actionChangePassword()
     }
 }
 
-SKGAdviceList SKGFilePlugin::advices() const
+SKGAdviceList SKGFilePlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGFilePlugin::advices");
+    SKGTRACEIN(10, "SKGFilePlugin::advice");
     SKGAdviceList output;
 
     //Backup
