@@ -30,10 +30,12 @@
 #include <kaboutdata.h>
 #include <kcolorscheme.h>
 #include <kstandarddirs.h>
+#include <kgenericfactory.h>
 
 #include <QDesktopServices>
 #include <QFileInfo>
 #include <QDir>
+#include <QFile>
 
 /**
  * This plugin factory.
@@ -68,11 +70,20 @@ bool SKGMonthlyPlugin::setupActions(SKGDocument* iDocument, const QStringList& i
 
     m_mainPage = new QWebView();
     m_mainPage->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
-    connect(m_mainPage, SIGNAL(linkClicked(QUrl)), this, SLOT(onOpen(QUrl)));
+    connect(m_mainPage, SIGNAL(linkClicked(QUrl)), SKGMainPanel::getMainPanel(), SLOT(openPage(QUrl)));
     SKGMainPanel::getMainPanel()->setMainWidget(m_mainPage);
     refreshMainPage();
     connect(m_currentBankDocument, SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(refreshMainPage()));
 
+    //Make needed paths
+    QString path = KStandardDirs::locateLocal("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/");
+
+    //Copy "default" directory in locale
+    foreach(const QString & file, KStandardDirs().findAllResources("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/*.html")) {
+        QFile(file).remove();
+        QFile(file).copy(path % QFileInfo(file).fileName());
+    }
+
     //Create yours actions here
     return true;
 }
@@ -135,26 +146,4 @@ bool SKGMonthlyPlugin::isInPagesChooser() const
 {
     return true;
 }
-
-void SKGMonthlyPlugin::onOpen(const QUrl& iLink)
-{
-    //Call operation plugin
-    QDomDocument doc("SKGML");
-    SKGTRACE << iLink.toString() << endl;
-
-    QStringList params = SKGServices::splitCSVLine(iLink.toString());
-    if (params.count() == 2) {
-        //Open special Skrooge page
-        doc.setContent(m_currentBankDocument->getParameter(params.at(1)));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(params.at(0)), -1, doc.toString());
-    } else {
-        //Open URL
-        QDesktopServices::openUrl(iLink);
-    }
-}
 #include "skgmonthlyplugin.moc"
