@@ -33,7 +33,7 @@
 #include <QPainter>
 #include <QPicture>
 #include <kaboutdata.h>
-
+#include <kgenericfactory.h>
 /**
  * This plugin factory.
  */
@@ -128,9 +128,10 @@ void SKGPrintPlugin::actionPrintPreview()
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGPrintPlugin::actionPrintPreview", err);
-    QPrintPreviewDialog preview(SKGMainPanel::getMainPanel());
-    connect(&preview, SIGNAL(paintRequested(QPrinter*)), this, SLOT(print(QPrinter*)));
-    preview.exec();
+    QPointer<QPrintPreviewDialog> dialog = new QPrintPreviewDialog(SKGMainPanel::getMainPanel());
+    connect(dialog, SIGNAL(paintRequested(QPrinter*)), this, SLOT(print(QPrinter*)));
+    dialog->exec();
+    delete dialog;
 }
 
 void SKGPrintPlugin::print(QPrinter* iPrinter)
