@@ -33,6 +33,7 @@
 #include <kstandardaction.h>
 #include <ktoolbarpopupaction.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
 
 /**
  * This plugin factory.
@@ -210,9 +211,9 @@ int SKGUndoRedoPlugin::getOrder() const
     return 4;
 }
 
-SKGAdviceList SKGUndoRedoPlugin::advices() const
+SKGAdviceList SKGUndoRedoPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGUndoRedoPlugin::advices");
+    SKGTRACEIN(10, "SKGUndoRedoPlugin::advice");
     SKGAdviceList output;
     //Get nb transaction
     int nbObject = m_currentDocument->getNbTransaction();
