@@ -28,6 +28,8 @@
 #include <klocale.h>
 #include <kfilterdev.h>
 #include <ksavefile.h>
+#include <kgenericfactory.h>
+
 #include <QCryptographicHash>
 #include <qfileinfo.h>
 
@@ -109,7 +111,9 @@ SKGError SKGImportPluginQif::importFile()
                         inPriceSection = false;
                     }
 
-                    if (QString::compare(line, "!account", Qt::CaseInsensitive) == 0 || QString::compare(line, "!type:cat", Qt::CaseInsensitive) == 0) {
+                    if (QString::compare(line, "!account", Qt::CaseInsensitive) == 0 ||
+                            QString::compare(line, "!type:cat", Qt::CaseInsensitive) == 0 ||
+                            QString::compare(line, "!type:class", Qt::CaseInsensitive) == 0) {
                         inWrongSection = true;
                     } else if (QString::compare(line, "!type:prices", Qt::CaseInsensitive) == 0) {
                         inPriceSection = true;
