@@ -111,6 +111,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(SKGDocument* iDocument)
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
+    connect(ui.kLabel, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 }
 
 SKGAccountBoardWidget::~SKGAccountBoardWidget()
@@ -194,7 +195,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
             if (!err) {
                 QString html;
                 if (!exist) {
-                    html = "<html><body>" % i18nc("Message", "First, you have to create at least one account<br>from <a href=\"___\">\"Bank and Account\"</a> page or <a href=\"__I\">import</a> operations.") % "</body></html>";
+                    html = "<html><body>" % i18nc("Message, do not translate URL (sk://...)", "First, you have to create at least one account<br>from <a href=\"skg://Skrooge_bank_plugin/\">\"Bank and Account\"</a> page or <a href=\"skg://import_operation\">import</a> operations.") % "</body></html>";
                 } else {
                     //Build where clause
                     QString wc;
@@ -270,7 +271,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                 account.getUnit(unitAccount);
                                 QString unitAccountSymbol = unitAccount.getSymbol();
 
-                                html += QString("<tr><td><a href=\"" % SKGServices::stringToHtml(name) % "\">") % SKGServices::stringToHtml(name) % "</a></td>"
+                                html += QString("<tr><td><a href=\"skg://Skrooge_operation_plugin/?account=" % KUrl::encode_string(name) % "\">") % SKGServices::stringToHtml(name) % "</a></td>"
                                         "<td align=\"right\">";
 
                                 if (!unitAccountSymbol.isEmpty() && primary.Symbol != unitAccountSymbol) {
@@ -293,7 +294,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                     "<td align=\"right\"><b>" % doc->formatMoney(sumTypeV1, primary) % "</b></td>"
                                     "</tr>";
                         }
-                        html += "<tr><td><b><a href=\"" % SKGServices::stringToHtml(i18nc("Noun, all items in a list", "All")) %
+                        html += "<tr><td><b><a href=\"skg://Skrooge_operation_plugin/?account=" % KUrl::encode_string(i18nc("Noun, all items in a list", "All")) %
                                 "\">" % SKGServices::stringToHtml(i18nc("Noun, the numerical total of a sum of values", "Total")) % "</a></b></td>"
                                 "<td align=\"right\"><b>" % doc->formatMoney(sumV1, primary) % "</b></td>"
                                 "</tr>";
@@ -305,28 +306,4 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
         }
     }
 }
-
-void SKGAccountBoardWidget::onOpen(const QString& iLink)
-{
-    //Call operation plugin
-    QDomDocument doc("SKGML");
-
-    if (iLink == "__I") {
-        QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction("import_operation");
-        if (action) action->trigger();
-    } else if (iLink != "___") {
-        doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("account", iLink);
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-    } else {
-        doc.setContent(getDocument()->getParameter("SKGBANK_DEFAULT_PARAMETERS"));
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge bank plugin"), -1, doc.toString());
-    }
-}
 #include "skgaccountboardwidget.moc"
