@@ -37,7 +37,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGAccountBoardWidget(SKGDocument* iDocument);
+    explicit SKGAccountBoardWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
@@ -62,7 +62,6 @@ public:
 private Q_SLOTS:
     void pageChanged();
     void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
-    void onOpen(const QString& iLink);
 
 private:
     Q_DISABLE_COPY(SKGAccountBoardWidget);
