@@ -24,6 +24,7 @@
 #include "skgbankboardwidget.h"
 #include "skgaccountboardwidget.h"
 #include "skgmainpanel.h"
+#include "skghtmlboardwidget.h"
 #include "skgaccountobject.h"
 #include "skgoperationobject.h"
 #include "skgsuboperationobject.h"
@@ -34,6 +35,8 @@
 
 #include <kactioncollection.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
+#include <kstandarddirs.h>
 
 /**
  * This plugin factory.
@@ -79,20 +82,33 @@ bool SKGBankPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
 
 int SKGBankPlugin::getNbDashboardWidgets()
 {
-    return 2;
+    return 4;
 }
 
 QString SKGBankPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    if (iIndex == 0) return i18nc("Noun, a list of bank accounts", "Accounts");
-    else if (iIndex == 1) return i18nc("Noun, a list of banks", "Banks");
+    if (iIndex == 0) return i18nc("Noun, a list of bank accounts", "Accounts (Light)");
+    else if (iIndex == 1) return i18nc("Noun, a list of bank accounts", "Accounts (Full)");
+    else if (iIndex == 2) return i18nc("Noun, a list of banks", "Banks (Light)");
+    else if (iIndex == 3) return i18nc("Noun, a list of banks", "Banks (Full)");
     return "";
 }
 
 SKGWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGAccountBoardWidget(m_currentBankDocument);
-    else if (iIndex == 1) return new SKGBankBoardWidget(m_currentBankDocument);
+    else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                     getDashboardWidgetTitle(iIndex),
+                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/account_table.html"),
+                                     QStringList() << "v_account_display", true);
+    else if (iIndex == 2) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                     getDashboardWidgetTitle(iIndex),
+                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/bank_table_light.html"),
+                                     QStringList() << "v_account_display");
+    else if (iIndex == 3) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                     getDashboardWidgetTitle(iIndex),
+                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/bank_table.html"),
+                                     QStringList() << "v_account_display", true);
     return NULL;
 }
 
@@ -175,9 +191,9 @@ void SKGBankPlugin::actionReconciliate()
     }
 }
 
-SKGAdviceList SKGBankPlugin::advices() const
+SKGAdviceList SKGBankPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGBankPlugin::advices");
+    SKGTRACEIN(10, "SKGBankPlugin::advice");
     SKGAdviceList output;
 
     //Get bank without accounts
