@@ -92,7 +92,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
 
 
             m_timer2.setSingleShot(true);
-            connect(&m_timer2, SIGNAL(timeout()), this, SLOT(onRefreshGraph()));
+            connect(&m_timer2, SIGNAL(timeout()), this, SLOT(onRefreshGraph()), Qt::QueuedConnection);
             m_timer2.start(300);
 
             connect(ui.kView->getShowWidget(), SIGNAL(stateChanged()), &m_timer2, SIGNAL(timeout()));
@@ -123,7 +123,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     ui.kView->getShowWidget()->setDefaultState("opened");
 
     m_timer.setSingleShot(true);
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshInfoZone()));
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshInfoZone()), Qt::QueuedConnection);
 
     //Add Standard KDE Icons to buttons to Accounts
     ui.kAccountCreatorUpdate->setIcon(KIcon("dialog-ok-apply"));
