@@ -41,7 +41,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGBankPluginWidget(SKGDocumentBank* iDocument);
+    explicit SKGBankPluginWidget(SKGDocumentBank* iDocument);
 
     /**
      * Default Destructor
