@@ -41,7 +41,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGBudgetPluginWidget(SKGDocument* iDocument);
+    explicit SKGBudgetPluginWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
