@@ -38,6 +38,7 @@ SKGInterestBoardWidget::SKGInterestBoardWidget(SKGDocument* iDocument)
 
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(ui.kLabel, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 }
 
 SKGInterestBoardWidget::~SKGInterestBoardWidget()
@@ -82,7 +83,7 @@ void SKGInterestBoardWidget::dataModified(const QString& iTableName, int iIdTran
                     double sum = 0;
                     for (int i = 0; i < nb; ++i) {
                         SKGAccountObject obj = objs.at(i);
-                        html += QString("<tr><td><a href=\"" % SKGServices::stringToHtml(obj.getName()) % "\">") % SKGServices::stringToHtml(obj.getName()) % "</a></td><td align=\"right\">";
+                        html += QString("<tr><td><a href=\"skg://Skrooge_calculator_plugin/?currentPage=0&account=" % KUrl::encode_string(obj.getName()) % "\">") % SKGServices::stringToHtml(obj.getName()) % "</a></td><td align=\"right\">";
 
                         QList<SKGAccountObject::SKGInterestItem> oInterestList;
                         double oInterests = 0;
@@ -97,7 +98,7 @@ void SKGInterestBoardWidget::dataModified(const QString& iTableName, int iIdTran
                             "</tr>";
                     html += "</table>";
                 } else {
-                    html += i18nc("A Message for the user about financial interests", "No interest defined for accounts<br>on the <a href=\"___\">\"Simulation\"</a> page.");
+                    html += i18nc("A Message for the user about financial interests", "No interest defined for accounts<br>on the <a href=\"skg://Skrooge_calculator_plugin/?currentPage=0\">\"Simulation\"</a> page.");
                 }
                 html += "</body></html>";
                 ui.kLabel->setText(html);
@@ -111,21 +112,4 @@ void SKGInterestBoardWidget::dataModified(const QString& iTableName, int iIdTran
     }
 }
 
-void SKGInterestBoardWidget::onOpen(const QString& iLink)
-{
-    //Call operation plugin
-    QDomDocument doc("SKGML");
-
-    doc.setContent(getDocument()->getParameter("SKGCALCULATOR_DEFAULT_PARAMETERS"));
-    QDomElement root = doc.documentElement();
-    if (root.isNull()) {
-        root = doc.createElement("parameters");
-        doc.appendChild(root);
-    }
-
-    if (iLink != "___") root.setAttribute("account", iLink);
-    root.setAttribute("currentPage", "0");
-
-    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge calculator plugin"), -1, doc.toString());
-}
 #include "skginterestboardwidget.moc"
