@@ -21,17 +21,20 @@
  */
 #include "skgcategoriesplugin.h"
 #include "skgcategoriespluginwidget.h"
-#include "skgcategoriesboardwidget.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
+#include "skghtmlboardwidget.h"
 #include "skgtransactionmng.h"
 #include "skgcategoryobject.h"
 #include "skgdocumentbank.h"
 
+
 #include <kmessagebox.h>
 #include <kactioncollection.h>
 #include <kaction.h>
 #include <kaboutdata.h>
+#include <kstandarddirs.h>
+#include <kgenericfactory.h>
 
 /**
  * This plugin factory.
@@ -100,15 +103,20 @@ QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
 
 SKGWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
 {
-    SKGWidget* w = new SKGCategoriesBoardWidget(m_currentBankDocument);
-
-    QDomDocument doc("SKGML");
-    QDomElement root = doc.createElement("parameters");
-    doc.appendChild(root);
-    root.setAttribute("mode", SKGServices::intToString(iIndex));
-
-    w->setState(doc.toString());
-    return w;
+    SKGTRACEIN(1, "SKGCategoriesPlugin::getDashboardWidget");
+    if (iIndex == 0) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                getDashboardWidgetTitle(iIndex),
+                                KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/categories_month_table.html"),
+                                QStringList() << "v_operation_consolidated", true);
+    else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                     getDashboardWidgetTitle(iIndex),
+                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/categories_variations.html"),
+                                     QStringList() << "v_operation_consolidated", true);
+    else if (iIndex == 2) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                     getDashboardWidgetTitle(iIndex),
+                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/budget_table.html"),
+                                     QStringList() << "v_budget", true);
+    return NULL;
 }
 
 void SKGCategoriesPlugin::refresh()
@@ -220,9 +228,9 @@ bool SKGCategoriesPlugin::isInPagesChooser() const
     return true;
 }
 
-SKGAdviceList SKGCategoriesPlugin::advices() const
+SKGAdviceList SKGCategoriesPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGCategoriesPlugin::advices");
+    SKGTRACEIN(10, "SKGCategoriesPlugin::advice");
     SKGAdviceList output;
     //Check unused categies
     bool exist = false;
