@@ -23,10 +23,6 @@
  */
 #include "skginterfaceplugin.h"
 
-#include <QObject>
-#include <QVariantList>
-#include <kgenericfactory.h>
-
 class SKGMainPanel;
 class KAction;
 class SKGDocumentBank;
@@ -43,7 +39,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGCategoriesPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGCategoriesPlugin(QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -129,7 +125,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advices() const;
+    virtual SKGAdviceList advice() const;
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
