@@ -39,7 +39,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGCategoriesPluginWidget(SKGDocumentBank* iDocument);
+    explicit SKGCategoriesPluginWidget(SKGDocumentBank* iDocument);
 
     /**
      * Default Destructor
