@@ -32,13 +32,13 @@
 #include <kactionmenu.h>
 #include <kfiledialog.h>
 #include <kaboutdata.h>
-
-#include <QTextCodec>
-#include <QDomDocument>
 #include <kencodingfiledialog.h>
 #include <KMessageBox>
 #include <kpassworddialog.h>
+#include <kgenericfactory.h>
 
+#include <QTextCodec>
+#include <QDomDocument>
 /**
  * This plugin factory.
  */
@@ -622,9 +622,9 @@ void SKGImportExportPlugin::openNotValidated() const
     if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
 }
 
-SKGAdviceList SKGImportExportPlugin::advices() const
+SKGAdviceList SKGImportExportPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGImportExportPlugin::advices");
+    SKGTRACEIN(10, "SKGImportExportPlugin::advice");
     SKGAdviceList output;
 
     //Check operations not validated
