@@ -39,8 +39,10 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
 
     ui.kIncomeLabel->setText("<a href=\"IC\">" % ui.kIncomeLabel->text() % "</a>");
     ui.kExpenseLabel->setText("<a href=\"EC\">" % ui.kExpenseLabel->text() % "</a>");
+    ui.kSavingLabel->setText("<a href=\"SP\">" % ui.kSavingLabel->text() % "</a>");
     ui.kIncome_previousLabel->setText("<a href=\"IP\">" % ui.kIncome_previousLabel->text() % "</a>");
     ui.kExpense_previousLabel->setText("<a href=\"EP\">" % ui.kExpense_previousLabel->text() % "</a>");
+    ui.kSaving_previousLabel->setText("<a href=\"SP\">" % ui.kSaving_previousLabel->text() % "</a>");
 
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
@@ -101,9 +103,9 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
     else wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now','-1 Month'))";
 
     if (iLink.startsWith(QLatin1String("I"))) wc = wc % " AND t_TYPEEXPENSE='+'";
-    else wc = wc % " AND t_TYPEEXPENSE='-'";
+    else if (iLink.startsWith(QLatin1String("E"))) wc = wc % " AND t_TYPEEXPENSE='-'";
 
-    wc = wc % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : " AND t_TRANSFER='N'") % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND r_refund_id=0");
+    wc = wc % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : " AND t_TRANSFER='N'") % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''");
 
     doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
     QDomElement root = doc.documentElement();
@@ -114,16 +116,24 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
     QString title;
     if (iLink == "IC") title = i18nc("Title of a list of operations", "Incomes of current month");
     else if (iLink == "EC") title = i18nc("Title of a list of operations", "Expenses of current month");
+    else if (iLink == "SC") title = i18nc("Title of a list of operations", "Savings of current month");
     else if (iLink == "IP") title = i18nc("Title of a list of operations", "Incomes of previous month");
     else if (iLink == "EP") title = i18nc("Title of a list of operations", "Expenses of previous month");
+    else if (iLink == "SP") title = i18nc("Title of a list of operations", "Savings of previous month");
 
-    if (m_menuTracked && m_menuTracked->isChecked() == false) root.setAttribute("operationTable", "v_operation_consolidated");
-    root.setAttribute("operationWhereClause", wc);
-    root.setAttribute("title", title);
-    root.setAttribute("title_icon", "view-financial-list");
-    root.setAttribute("currentPage", "-1");
+    if (QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier) {
+        //Call debug plugin
+        root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE " % wc);
 
-    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Debug plugin"), -1, doc.toString());
+    } else {
+        root.setAttribute("operationWhereClause", wc);
+        root.setAttribute("title", title);
+        root.setAttribute("title_icon", "view-financial-list");
+        root.setAttribute("currentPage", "-1");
+
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+    }
 }
 
 void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
@@ -146,9 +156,9 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
 
             SKGStringListList listTmp;
             SKGError err = getDocument()->executeSelectSqliteOrder(
-                               "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_consolidated WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') "
+                               "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') "
                                % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : "AND t_TRANSFER='N'")
-                               % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND r_refund_id=0")
+                               % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''")
                                % " group by d_DATEMONTH, t_TYPEEXPENSE",
                                listTmp);
             if (!err) {
