@@ -37,7 +37,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGOperationBoardWidget(SKGDocument* iDocument);
+    explicit SKGOperationBoardWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
