@@ -22,7 +22,6 @@
 #include "skgoperationplugin.h"
 #include "skgoperationpluginwidget.h"
 #include "skgoperationboardwidget.h"
-#include "skgbookmarkboardwidget.h"
 #include "skgtraces.h"
 #include "skgoperationobject.h"
 #include "skgaccountobject.h"
@@ -35,6 +34,7 @@
 #include "skgtransactionmng.h"
 #include "skgmainpanel.h"
 #include "skgtableview.h"
+#include "skghtmlboardwidget.h"
 #include "skgruleobject.h"
 #include "skgoperation_settings.h"
 #include "skgdocumentbank.h"
@@ -42,6 +42,8 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
+#include <kstandarddirs.h>
 
 #include <QDomDocument>
 
@@ -236,7 +238,10 @@ QString SKGOperationPlugin::getDashboardWidgetTitle(int iIndex)
 SKGWidget* SKGOperationPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGOperationBoardWidget(m_currentBankDocument);
-    else if (iIndex == 1) return new SKGBookmarkBoardWidget(m_currentBankDocument);
+    else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                     getDashboardWidgetTitle(iIndex),
+                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/highlighted_operations.html"),
+                                     QStringList() << "operation");
     return NULL;
 }
 
@@ -782,9 +787,9 @@ void SKGOperationPlugin::actionOpenSubOperations()
     if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
 }
 
-SKGAdviceList SKGOperationPlugin::advices() const
+SKGAdviceList SKGOperationPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::advices");
+    SKGTRACEIN(10, "SKGOperationPlugin::advice");
     SKGAdviceList output;
 
     //Search duplicate number on operation
