@@ -24,10 +24,6 @@
 #include "skginterfaceplugin.h"
 #include "ui_skgoperationpluginwidget_pref.h"
 
-#include <QObject>
-#include <QVariantList>
-#include <kgenericfactory.h>
-
 class SKGMainPanel;
 class KAction;
 class SKGDocumentBank;
@@ -44,7 +40,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGOperationPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGOperationPlugin(QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -150,7 +146,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advices() const;
+    virtual SKGAdviceList advice() const;
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
