@@ -54,7 +54,7 @@ SKGOperationPluginWidget::SKGOperationPluginWidget(SKGDocumentBank* iDocument)
     if (!iDocument) return;
 
     m_timer.setSingleShot(true);
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onRefreshInformationZone()));
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onRefreshInformationZone()), Qt::QueuedConnection);
 
     ui.setupUi(this);
 
@@ -1134,8 +1134,6 @@ void SKGOperationPluginWidget::setState(const QString& iState)
     if (!title.isEmpty()) {
         ui.kTitle->setComment("<html><body><b>" % SKGServices::stringToHtml(title) % "</b></body></html>");
         ui.kTitle->show();
-    } else {
-        ui.kTitle->hide();
     }
     if (!title_icon.isEmpty()) ui.kTitle->setPixmap(KIcon(title_icon).pixmap(22, 22), KTitleWidget::ImageLeft);
 
@@ -1238,7 +1236,7 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
             SKGStringListList listAccount;
             getDocument()->executeSelectSqliteOrder(QString("SELECT t_ICON, t_name from v_account_display ") % (m_showClosedAccounts ? "" : "where t_close='N' ") % "order by t_name", listAccount);
 
-            int nbAccounts = listAccount.count();
+            int nbAccounts = listAccount.count() - 1;
             if (nbAccounts == 0) {
                 ui.kTitle->setText(i18nc("Message", "First you have to create an account."));
                 ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22) , KTitleWidget::ImageLeft);
@@ -1249,14 +1247,18 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
                 //Set show widget
                 show->clear();
 
-                show->addGroupedItem("all", i18nc("Option to for display of operations", "All"), "", "1=1", "account");
+                if (nbAccounts != 1) show->addGroupedItem("all", i18nc("Option to for display of operations", "All"), "", "1=1", "account");
                 QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                 QString uncheck;
-                for (int i = 1; i < nbAccounts; ++i) { //Ignore header
+                for (int i = 1; i <= nbAccounts; ++i) { //Ignore header
                     QString iconName = dirLogo.absoluteFilePath(listAccount.at(i).at(0));
                     QIcon icon(iconName);
                     QString text = listAccount.at(i).at(1);
                     QString id = "##_" % text.remove(';');
+                    if (nbAccounts == 1) {
+                        if (currentState.startsWith(QLatin1String("all;"))) currentState = currentState.replace("all;", id % ";");
+                        if (!currentState.startsWith(QLatin1String("##_"))) currentState = id % ";" % (currentState.isEmpty() ? "operations;hide" : currentState);
+                    }
                     ui.kAccountEdit->addItem(icon, text);
                     ui.kPaymentAccountEdit->addItem(icon, text);
 
@@ -1270,7 +1272,7 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
                 for (int i = 1; i < nb; ++i) {
                     show->setListIdToUncheckWhenChecked(i, uncheck % ";all");
                 }
-                show->setListIdToUncheckWhenChecked(0, uncheck);
+                if (nbAccounts != 1) show->setListIdToUncheckWhenChecked(0, uncheck);
 
                 show->addSeparator();
                 show->addGroupedItem("operations", i18nc("Option to for display of operations", "Operations"), "view-financial-list", "d_date!='0000-00-00' AND t_template='N'",
@@ -1280,8 +1282,8 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
                 show->addSeparator();
                 show->addGroupedItem("hidenone", i18nc("Option to for display of operations", "All"), "dialog-ok", "1=1", "checked");
                 show->addGroupedItem("hide", i18nc("Option to for display of operations", "Hide all checked operations"), "dialog-ok", "t_status<>'Y'", "checked");
-                show->addGroupedItem("hide1w", i18nc("Option to for display of operations", "Hide checked operations > 1 week"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 week')", "checked");
-                show->addGroupedItem("hide2w", i18nc("Option to for display of operations", "Hide checked operations > 2 weeks"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-2 week')", "checked");
+                show->addGroupedItem("hide1w", i18nc("Option to for display of operations", "Hide checked operations > 1 week"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-7 day')", "checked");
+                show->addGroupedItem("hide2w", i18nc("Option to for display of operations", "Hide checked operations > 2 weeks"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-14 day')", "checked");
                 show->addGroupedItem("hide1m", i18nc("Option to for display of operations", "Hide checked operations > 1 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-1 month')", "checked");
                 show->addGroupedItem("hide3m", i18nc("Option to for display of operations", "Hide checked operations > 3 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-3 month')", "checked");
                 show->addGroupedItem("hide6m", i18nc("Option to for display of operations", "Hide checked operations > 6 months"), "dialog-ok", "t_status<>'Y' OR d_date>date('now', '-6 month')", "checked");
@@ -1315,7 +1317,7 @@ void SKGOperationPluginWidget::dataModified(const QString& iTableName, int iIdTr
         }
         if (iTableName == "operation" || iTableName.isEmpty()) {
             SKGMainPanel::fillWithDistinctValue(ui.kTypeEdit, getDocument(), "operation", "t_mode", "", true);
-            SKGMainPanel::fillWithDistinctValue(ui.kCommentEdit, getDocument(), "operation", "t_comment", "", true);
+            SKGMainPanel::fillWithDistinctValue(ui.kCommentEdit, getDocument(), "v_operation_all_comment", "t_comment", "", true);
 
             //Set type number
             m_numberFieldIsNotUptodate = true;
@@ -1371,6 +1373,7 @@ void SKGOperationPluginWidget::onResetInternalFilter()
 
     if (m_objectModel) m_objectModel->setTable("v_operation_display_all");
     ui.kOperationView->getShowWidget()->setEnabled(true);
+    ui.kTitle->hide();
 
     setState(getDocument()->getParameter(getDefaultStateAttribute()));
 
