@@ -46,7 +46,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGOperationPluginWidget(SKGDocumentBank* iDocument);
+    explicit SKGOperationPluginWidget(SKGDocumentBank* iDocument);
 
     /**
      * Default Destructor
