@@ -29,6 +29,7 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
 
 /**
  * This plugin factory.
@@ -114,9 +115,9 @@ bool SKGPayeePlugin::isInPagesChooser() const
     return true;
 }
 
-SKGAdviceList SKGPayeePlugin::advices() const
+SKGAdviceList SKGPayeePlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGPayeePlugin::advices");
+    SKGTRACEIN(10, "SKGPayeePlugin::advice");
     SKGAdviceList output;
     //Check unused payee
     bool exist = false;
