@@ -35,7 +35,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGPayeePluginWidget(SKGDocument* iDocument);
+    explicit SKGPayeePluginWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
