@@ -38,6 +38,7 @@
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
 
 #include <QDomDocument>
 
@@ -301,4 +302,47 @@ void SKGReportPlugin::actionOpenReport()
     }
 }
 
+SKGAdviceList SKGReportPlugin::advice() const
+{
+    SKGTRACEIN(10, "SKGOperationPlugin::advice");
+    SKGAdviceList output;
+
+    //Very old operation
+    bool exist = false;
+    m_currentBankDocument->existObjects("operation", "d_date<=date('now', '-50 year') AND d_date<>'0000-00-00'", exist);
+    if (exist) {
+        SKGAdvice ad;
+        ad.setUUID("skgreportplugin_veryold");
+        ad.setPriority(3);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Some operations are very old"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "For performances reasons, very old operations are not taken into account in graph report. Check if these operations are normal."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open very old operations"));
+        ad.setAutoCorrections(autoCorrections);
+        output.push_back(ad);
+    }
+    return output;
+}
+
+SKGError SKGReportPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution) const
+{
+    if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgreportplugin_veryold"))) {
+        //Call operation plugin
+        QDomDocument doc("SKGML");
+        doc.setContent(m_currentBankDocument->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
+        QDomElement root = doc.documentElement();
+        if (root.isNull()) {
+            root = doc.createElement("parameters");
+            doc.appendChild(root);
+        }
+
+        root.setAttribute("operationWhereClause", "d_date<=date('now', '-50 year') AND d_date<>'0000-00-00'");
+        root.setAttribute("title", i18nc("Noun, a list of items", "Very old operations"));
+        root.setAttribute("title_icon", "security-low");
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+        return SKGError();
+    }
+    return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
+}
+
 #include "skgreportplugin.moc"
