@@ -43,7 +43,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     if (!iDocument) return;
 
     m_timer.setSingleShot(true);
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshActivated()));
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshActivated()), Qt::QueuedConnection);
 
     ui.setupUi(this);
 
@@ -1028,6 +1028,9 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 if (!attLine.isEmpty()) condition = '(' % condition % ") AND " % attLine % " NOT LIKE '%#NULL#%'";
                 if (!attCol.isEmpty()) condition = '(' % condition % ") AND " % attCol % " NOT LIKE '%#NULL#%'";
 
+                //Limit size of the result
+                condition = '(' % condition % ") AND d_date>date('now', '-50 year')";
+
                 QString coef;
                 if (ui.kCorrectedBy->currentIndex() > 0 && mode != 3) {
                     SKGUnitObject unit = ui.kCorrectedBy->getUnit();
