@@ -21,7 +21,6 @@
  */
 #include "skgscheduledplugin.h"
 #include "skgscheduledpluginwidget.h"
-#include "skgscheduledboardwidget.h"
 #include "skgscheduled_settings.h"
 #include "skgrecurrentoperationobject.h"
 #include "skgtraces.h"
@@ -29,10 +28,13 @@
 #include "skgtransactionmng.h"
 #include "skgdocumentbank.h"
 #include "skgsuboperationobject.h"
+#include "skghtmlboardwidget.h"
 
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
+#include <kstandarddirs.h>
 
 /**
  * This plugin factory.
@@ -123,7 +125,10 @@ QString SKGScheduledPlugin::getDashboardWidgetTitle(int iIndex)
 
 SKGWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
 {
-    if (iIndex == 0) return new SKGScheduledBoardWidget(m_currentBankDocument);
+    if (iIndex == 0) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                getDashboardWidgetTitle(iIndex),
+                                KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/scheduled_operations.html"),
+                                QStringList() << "v_recurrentoperation_display");
     return NULL;
 }
 
@@ -298,9 +303,9 @@ void SKGScheduledPlugin::actionScheduleOperation()
     }
 }
 
-SKGAdviceList SKGScheduledPlugin::advices() const
+SKGAdviceList SKGScheduledPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGScheduledPlugin::advices");
+    SKGTRACEIN(10, "SKGScheduledPlugin::advice");
     SKGAdviceList output;
 
     //Recurrent operation with the last inserted operation having a different amount
