@@ -26,7 +26,7 @@
 #include "skgobjectmodel.h"
 #include "skgrecurrentoperationobject.h"
 #include "skgtransactionmng.h"
-#include <skgoperationobject.h>
+#include "skgoperationobject.h"
 
 #include <klineedit.h>
 
@@ -175,6 +175,7 @@ void SKGScheduledPluginWidget::onJumpToTheOperation()
             root.setAttribute("selection", op.getUniqueID());
             root.setAttribute("title", title);
             root.setAttribute("title_icon", "chronometer");
+            root.setAttribute("template", "Y");
 
             SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
         }
