@@ -37,7 +37,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGScheduledPluginWidget(SKGDocumentBank* iDocument);
+    explicit SKGScheduledPluginWidget(SKGDocumentBank* iDocument);
 
     /**
      * Default Destructor
