@@ -34,6 +34,7 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
 
 /**
  * This plugin factory.
@@ -48,7 +49,7 @@ SKGSearchPlugin::SKGSearchPlugin(QObject* iParent, const QVariantList& /*iArg*/)
 {
     SKGTRACEIN(10, "SKGSearchPlugin::SKGSearchPlugin");
     m_timer.setSingleShot(true);
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(raiseAlarms()));
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(raiseAlarms()), Qt::QueuedConnection);
 }
 
 SKGSearchPlugin::~SKGSearchPlugin()
@@ -374,9 +375,9 @@ bool SKGSearchPlugin::isInPagesChooser() const
     return true;
 }
 
-SKGAdviceList SKGSearchPlugin::advices() const
+SKGAdviceList SKGSearchPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGSearchPlugin::advices");
+    SKGTRACEIN(10, "SKGSearchPlugin::advice");
     SKGAdviceList output;
 
     //Alarms
