@@ -54,6 +54,9 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     ui.kUpdate->setIcon(KIcon("dialog-ok-apply"));
     ui.kAdd->setIcon(KIcon("list-add"));
     ui.kSearch->setIcon(KIcon("edit-find"));
+    QStringList overlayopen;
+    overlayopen.push_back("skg_open");
+    ui.kOpenReport->setIcon(KIcon("view-investment", NULL, overlayopen));
 
     ui.kTopBtn->setIcon(KIcon("arrow-up-double"));
     ui.kUpBtn->setIcon(KIcon("arrow-up"));
@@ -64,21 +67,21 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(KIcon("edit-find"), i18n("Search"), i18n("Display the edition panel for searches"), list);
+        ui.kWidgetSelector->addButton(KIcon("edit-find"), i18n("Search"), i18n("Display the edit panel for searches"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
         list.push_back(ui.kActionGrp);
-        ui.kWidgetSelector->addButton(KIcon("view-refresh"), i18n("Update"), i18n("Display the edition panel for updates"), list);
+        ui.kWidgetSelector->addButton(KIcon("view-refresh"), i18n("Update"), i18n("Display the edit panel for updates"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
         list.push_back(ui.kAlarmFrm);
-        ui.kWidgetSelector->addButton(KIcon("dialog-warning"), i18n("Alarm"), i18n("Display the edition panel for alarm"), list);
+        ui.kWidgetSelector->addButton(KIcon("dialog-warning"), i18n("Alarm"), i18n("Display the edit panel for alarm"), list);
     }
 
     //Fill combo boxes
@@ -258,10 +261,10 @@ void SKGSearchPluginWidget::onAddRule()
     SKGMainPanel::displayErrorMessage(err);
 }
 
-void SKGSearchPluginWidget::onSearch()
+void SKGSearchPluginWidget::onOpen()
 {
     SKGError err;
-    SKGTRACEINRC(1, "SKGSearchPluginWidget::onSearch", err);
+    SKGTRACEINRC(1, "SKGSearchPluginWidget::onOpen", err);
     SKGRuleObject rule;
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     rule = SKGRuleObject(getDocument());
@@ -271,7 +274,7 @@ void SKGSearchPluginWidget::onSearch()
     QString xml = getXMLActionDefinition();
     if (!err) err = rule.setActionType(xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType(ui.kWidgetSelector->getSelectedMode()));
     if (!err) err = rule.setXMLActionDefinition(xml);
-    if (!err) open(rule);
+    if (!err) open(rule, (sender() == ui.kSearch ? SKGSearchPluginWidget::TABLE : SKGSearchPluginWidget::REPORT));
     QApplication::restoreOverrideCursor();
 
     //Display error
@@ -486,7 +489,7 @@ void SKGSearchPluginWidget::onBottom()
     SKGMainPanel::displayErrorMessage(err);
 }
 
-void SKGSearchPluginWidget::open(const SKGRuleObject& iRule)
+void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
 {
     _SKGTRACEIN(10, "SKGSearchPluginWidget::open");
 
@@ -506,20 +509,25 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule)
     } else {
         //Call operation plugin
         QDomDocument doc("SKGML");
-        doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
+        doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(iMode == TABLE ? "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS" : "SKGREPORT_DEFAULT_PARAMETERS"));
         QDomElement root = doc.documentElement();
         if (root.isNull()) {
             root = doc.createElement("parameters");
             doc.appendChild(root);
         }
 
-        root.setAttribute("operationTable", "v_operation_consolidated");
         root.setAttribute("operationWhereClause", wc);
         root.setAttribute("title", title);
         root.setAttribute("title_icon", "edit-find");
-        root.setAttribute("currentPage", "-1");
 
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+        if (iMode == TABLE) {
+            root.setAttribute("operationTable", "v_operation_consolidated");
+            root.setAttribute("currentPage", "-1");
+            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+        } else {
+            root.setAttribute("period", "0");
+            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge report plugin"), -1, doc.toString());
+        }
     }
 }
 
