@@ -28,6 +28,7 @@
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
 
 /**
  * This plugin factory.
@@ -107,9 +108,9 @@ bool SKGTrackerPlugin::isInPagesChooser() const
     return true;
 }
 
-SKGAdviceList SKGTrackerPlugin::advices() const
+SKGAdviceList SKGTrackerPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGTrackerPlugin::advices");
+    SKGTRACEIN(10, "SKGTrackerPlugin::advice");
     SKGAdviceList output;
     //Search old trackers
     SKGStringListList result;
