@@ -35,7 +35,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGTrackerPluginWidget(SKGDocument* iDocument);
+    explicit SKGTrackerPluginWidget(SKGDocument* iDocument);
 
     /**
      * Default Destructor
