@@ -81,6 +81,7 @@ SKGUnitBoardWidget::SKGUnitBoardWidget(SKGDocument* iDocument)
 
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
+    connect(ui.kLabel, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 }
 
 SKGUnitBoardWidget::~SKGUnitBoardWidget()
@@ -130,7 +131,7 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
     SKGTRACEIN(10, "SKGUnitBoardWidget::dataModified");
     Q_UNUSED(iIdTransaction);
 
-    if (iTableName == "unit" || iTableName.isEmpty()) {
+    if (iTableName == "v_unit_display" || iTableName.isEmpty()) {
         KLocale* locale = KGlobal::locale();
         SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
         if (doc && locale) {
@@ -182,7 +183,9 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                             lastTitle = type;
                             html += "<tr><td><b>" % SKGServices::stringToHtml(lastTitle) % "</b></td></tr>";
                         }
-                        html += QString("<tr><td><a href=\"" % SKGServices::stringToHtml(obj.getSymbol()) % "\">") % SKGServices::stringToHtml(obj.getDisplayName()) % "</a></td><td align=\"right\">";
+                        html += QString("<tr><td><a href=\"skg://Skrooge_operation_plugin/?operationWhereClause=rc_unit_id=" % SKGServices::intToString(obj.getID()) %
+                                        "&title=" % KUrl::encode_string(i18nc("A list of operations made on the specified unit", "Operations with unit equal to '%1'",  obj.getName())) %
+                                        "&title_icon=view-currency-list&currentPage=-1" % "\">") % SKGServices::stringToHtml(obj.getDisplayName()) % "</a></td><td align=\"right\">";
                         if (obj.getType() == SKGUnitObject::INDEX) primary.Symbol = ' ';
                         html += doc->formatMoney(SKGServices::stringToDouble(obj.getAttribute("f_CURRENTAMOUNT")), primary);
                         html += "</td><td>(";
@@ -192,7 +195,7 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                     }
                     html += "</table>";
                 } else {
-                    html += i18nc("Message about not having any financial Share or financial index in the document", "No share or index defined<br>on the <a href=\"___\">\"Units\"</a> page.");
+                    html += i18nc("Message about not having any financial Share or financial index in the document", "No share or index defined<br>on the <a href=\"skg://Skrooge_unit_plugin\">\"Units\"</a> page.");
                 }
                 html += "</body></html>";
                 ui.kLabel->setText(html);
@@ -206,37 +209,4 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
     }
 }
 
-void SKGUnitBoardWidget::onOpen(const QString& iLink)
-{
-    QDomDocument doc("SKGML");
-    if (iLink != "___") {
-        SKGUnitObject unit(static_cast<SKGDocumentBank*>(getDocument()));
-        unit.setSymbol(iLink);
-        unit.load();
-        int unitid = unit.getID();
-
-        //Build where clause and title
-        QString wc = "rc_unit_id=" % SKGServices::intToString(unitid);
-        QString title = i18nc("A list of operations made on the specified unit", "Operations with unit equal to '%1'",  unit.getName());
-
-        //Open
-        //Call operation plugin
-        doc.setContent(getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-        QDomElement root = doc.documentElement();
-        if (root.isNull()) {
-            root = doc.createElement("parameters");
-            doc.appendChild(root);
-        }
-
-        root.setAttribute("operationWhereClause", wc);
-        root.setAttribute("title", title);
-        root.setAttribute("title_icon", "view-currency-list");
-        root.setAttribute("currentPage", "-1");
-
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
-    } else {
-        doc.setContent(getDocument()->getParameter("SKGUNIT_DEFAULT_PARAMETERS"));
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"), -1, doc.toString());
-    }
-}
 #include "skgunitboardwidget.moc"
