@@ -25,6 +25,7 @@
 #include "skgunit_settings.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
+#include "skghtmlboardwidget.h"
 #include "skgtransactionmng.h"
 #include "skgdocumentbank.h"
 #include "skgunitvalueobject.h"
@@ -33,6 +34,9 @@
 #include <kactioncollection.h>
 #include <kaction.h>
 #include <kaboutdata.h>
+#include <kgenericfactory.h>
+#include <kstandarddirs.h>
+#include <kcomponentdata.h>
 
 /**
  * This plugin factory.
@@ -79,18 +83,23 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
 
 int SKGUnitPlugin::getNbDashboardWidgets()
 {
-    return 1;
+    return 2;
 }
 
 QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
 {
     if (iIndex == 0) return i18nc("Noun, the title of a section", "Quotes");
+    else if (iIndex == 1) return i18nc("Noun, the title of a section", "Stock portfolio");
     return "";
 }
 
 SKGWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) return new SKGUnitBoardWidget(m_currentBankDocument);
+    else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                     getDashboardWidgetTitle(iIndex),
+                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/portfolio.html"),
+                                     QStringList() << "v_operation_display");
     return NULL;
 }
 
@@ -252,9 +261,9 @@ void SKGUnitPlugin::actionSplitShare()
     }
 }
 
-SKGAdviceList SKGUnitPlugin::advices() const
+SKGAdviceList SKGUnitPlugin::advice() const
 {
-    SKGTRACEIN(10, "SKGUnitPlugin::advices");
+    SKGTRACEIN(10, "SKGUnitPlugin::advice");
     SKGAdviceList output;
 
     //Get all currencies
@@ -334,6 +343,25 @@ SKGAdviceList SKGUnitPlugin::advices() const
         output.push_back(ad);
     }
 
+    //Unit with very old values
+    m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=date('now', '-50 year'))", result);
+    nb = result.count();
+    for (int i = 1; i < nb; ++i) { //Ignore header
+        //Get parameters
+        QStringList line = result.at(i);
+        QString unit = line.at(0);
+
+        SKGAdvice ad;
+        ad.setUUID("skgunitplugin_veryold|" % unit);
+        ad.setPriority(3);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Unit '%1' has very old values", unit));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "Unit '%1' has very old values. Check if this is normal."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit currencies"));
+        ad.setAutoCorrections(autoCorrections);
+        output.push_back(ad);
+    }
+
     return output;
 }
 
@@ -341,9 +369,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
 {
     if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_primaryunit|"))) {
         if (iSolution == 1) {
-            QDomDocument doc("SKGML");
-            doc.setContent(m_currentBankDocument->getParameter("SKGUNIT_DEFAULT_PARAMETERS"));
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"), -1, doc.toString());
+            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"));
         } else {
             //Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 26);
@@ -369,9 +395,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_secondaryunit|"))) {
         if (iSolution == 1) {
-            QDomDocument doc("SKGML");
-            doc.setContent(m_currentBankDocument->getParameter("SKGUNIT_DEFAULT_PARAMETERS"));
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"), -1, doc.toString());
+            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"));
         } else {
             //Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
@@ -397,9 +421,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         return SKGError();
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_notdownloaded|"))) {
         if (iSolution == 0) {
-            QDomDocument doc("SKGML");
-            doc.setContent(m_currentBankDocument->getParameter("SKGUNIT_DEFAULT_PARAMETERS"));
-            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"), -1, doc.toString());
+            SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"));
         } else {
             //Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
@@ -418,6 +440,9 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
     } else if (iAdviceIdentifier == "skgunitplugin_unused") {
         deleteUnusedUnits();
         return SKGError();
+    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_veryold|"))) {
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge unit plugin"));
+        return SKGError();
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
 }
