@@ -121,6 +121,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     menu->addAction(m_upload);
     ui.kGetNewHotStuff->setMenu(menu);
 
+    ui.kUnitOpen->setIcon(KIcon("skg_open"));
+    connect(ui.kUnitOpen, SIGNAL(clicked(bool)), this, SLOT(onOpenURL()));
+
     KAction* downloadLastAction = new KAction(KIcon("download"), i18n("download last value only"), this);
     downloadLastAction->setData(SKGUnitObject::LAST);
     connect(downloadLastAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), SLOT(onDownloadUnitValue()));
@@ -250,7 +253,7 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
 
     //Fill combo box for currency
     m_timer.setSingleShot(true);
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshUnitList()));
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(refreshUnitList()), Qt::QueuedConnection);
     m_timer.start(500);;
 }
 
@@ -318,6 +321,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
     }
     ui.kUnitValueFrame->setEnabled(nbSelect == 1);
     ui.kUnitValueDownload->setEnabled(nbSelect > 0);
+    ui.kUnitOpen->setEnabled(nbSelect > 0);
 
     //Fill values
     QString wc = "rd_unit_id=(select id from unit where t_name='" % SKGServices::stringToSqlString(ui.kNameCreatorUnit->text()) % "')";
@@ -332,7 +336,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
 
     //Draw plot
     SKGStringListList table;
-    getDocument()->getConsolidatedView("v_unitvalue_display", "d_date", "t_UNIT", "f_quantity", "TOTAL", wc, table , "");
+    getDocument()->getConsolidatedView("v_unitvalue_display", "d_date", "t_UNIT", "f_quantity", "TOTAL", wc % " AND d_date>date('now', '-50 year')" , table , "");
 
     SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
     SKGServices::SKGUnitInfo secondaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
@@ -784,4 +788,23 @@ void SKGUnitPluginWidget::onPutNewHotStuff()
         QFile(zipFileName).remove();
     }
 }
+
+void SKGUnitPluginWidget::onOpenURL()
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGUnitPluginWidget::onOpenURL", err);
+
+    SKGObjectBase::SKGListSKGObjectBase selection = ui.kUnitTableViewEdition->getView()->getSelectedObjects();
+    int nb = selection.count();
+    if (nb) {
+        for (int i = 0; !err && i < nb; ++i) {
+            SKGUnitObject unit = selection.at(i);
+            err = unit.openURL();
+        }
+    }
+
+    //Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
 #include "skgunitpluginwidget.moc"
