@@ -41,7 +41,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGUnitPluginWidget(SKGDocumentBank* iDocument);
+    explicit SKGUnitPluginWidget(SKGDocumentBank* iDocument);
 
     /**
      * Default Destructor
@@ -138,6 +138,7 @@ private Q_SLOTS:
     void onSourceChanged();
     void onGetNewHotStuff();
     void onPutNewHotStuff();
+    void onOpenURL();
     void cleanEditor();
     void refreshUnitList();
     void fillSourceList();
