@@ -41,7 +41,7 @@
 #define SRC_HIGHLIGHTED             "Highlighted Operations"
 #define SRC_SCHEDULED               "Scheduled Operations"
 #define SRC_UNITS                   "Units"
-#define SRC_ADVICES                 "Advices"
+#define SRC_ADVICES                 "Advice"
 #define SRC_INTERESTS               "Interests"
 #define SRC_ALARMS                  "Alarms"
 
@@ -82,7 +82,7 @@ bool SKGDataEngine::updateSourceEvent(const QString& source)
     } else if (source == SRC_UNITS) {
         return getUnitsData();
     } else if (source == SRC_ADVICES) {
-        return getAdvicesData();
+        return getAdviceData();
     } else if (source == SRC_INTERESTS) {
         return getInterestsData();
     }
@@ -237,22 +237,22 @@ bool SKGDataEngine::getUnitsData()
     return true;
 }
 
-bool SKGDataEngine::getAdvicesData()
+bool SKGDataEngine::getAdviceData()
 {
     removeAllData(SRC_ADVICES);
     if (!document) return false;
 
-    //Get list of ignored advices
+    //Get list of ignored advice
     QString currentMonth = QDate::currentDate().toString("yyyy-MM");
-    QStringList ignoredAdvices = getDocument()->getParameters("advices", "t_value='I' OR t_value='I_" % currentMonth % '\'');
+    QStringList ignoredAdvice = getDocument()->getParameters("advice", "t_value='I' OR t_value='I_" % currentMonth % '\'');
 
-    //Build the list of all advices by requesting all plugins
+    //Build the list of all advice by requesting all plugins
     int index = 0;
     while (index >= 0) {
         SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
         if (plugin) {
-            foreach(const SKGAdvice & advice, plugin->advices()) {
-                if (!ignoredAdvices.contains(advice.getUUID()) && !ignoredAdvices.contains(SKGServices::splitCSVLine(advice.getUUID(), '|').at(0))) {
+            foreach(const SKGAdvice & advice, plugin->advice()) {
+                if (!ignoredAdvice.contains(advice.getUUID()) && !ignoredAdvice.contains(SKGServices::splitCSVLine(advice.getUUID(), '|').at(0))) {
                     QVariantList values;
                     values.append(SKGServices::intToString(advice.getPriority()));
                     values.append(advice.getShortMessage());
