@@ -100,9 +100,9 @@ protected:
     virtual bool getUnitsData();
 
     /**
-     * Get data on Advices
+     * Get data on Advice
      */
-    virtual bool getAdvicesData();
+    virtual bool getAdviceData();
 
     /**
      * Get data on Interests
