@@ -38,7 +38,7 @@ public:
      * Constructor
      * @param parent the parent
      */
-    SKGBKWidgetCollectionDesignerPlugin(QObject* parent = 0);
+    explicit SKGBKWidgetCollectionDesignerPlugin(QObject* parent = 0);
 
     /**
      * To get the list of widgets
