@@ -47,12 +47,12 @@ public:
      * @param iParentAttribute the attribute to find the parent of an object clause to find children
      * @param iResetOnCreation to reset data during creation
      */
-    SKGObjectModel(SKGDocumentBank* iDocument,
-                   const QString& iTable,
-                   const QString& iWhereClause,
-                   QWidget* parent = NULL,
-                   const QString& iParentAttribute = "",
-                   bool iResetOnCreation = true);
+    explicit SKGObjectModel(SKGDocumentBank* iDocument,
+                            const QString& iTable,
+                            const QString& iWhereClause,
+                            QWidget* parent = NULL,
+                            const QString& iParentAttribute = "",
+                            bool iResetOnCreation = true);
 
     /**
      * Destructor
