@@ -43,15 +43,13 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGPropertyEditor(QWidget* parent = 0);
-
+    explicit SKGPropertyEditor(QWidget* parent = 0);
 
     /**
      * Default Destructor
      */
     virtual ~SKGPropertyEditor();
 
-
     /**
      * Set parameters
      * @param iDocument the document
@@ -61,7 +59,6 @@ public:
      */
     virtual void setParameters(SKGDocument* iDocument, const QString& iTable, const QStringList& iEditableAttribute, const QStringList& iOtherAttributes);
 
-
     /**
      * Set values in widgets
      * @param iXML the XML String describing the operation line
