@@ -42,7 +42,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGQueryCreator(QWidget* parent = 0);
+    explicit SKGQueryCreator(QWidget* parent = 0);
 
     /**
      * Default Destructor
