@@ -22,7 +22,7 @@
 #include "skgquerycreatordesignerplugin.h"
 #include "skgquerycreator.h"
 
-#include "kicon.h"
+#include <kicon.h>
 
 #include <QtPlugin>
 
