@@ -231,14 +231,27 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
 SKGError SKGAccountObject::setType(SKGAccountObject::AccountType iType)
 {
     SKGError err;
-    if (!err) err = setAttribute("t_type", (iType == CURRENT ? "C" : (iType == CREDITCARD ? "D" : (iType == ASSETS ? "A" : (iType == INVESTMENT ? "I" : (iType == WALLET ? "W" : (iType == LOAN ? "L" : "O")))))));
+    if (!err) err = setAttribute("t_type", (iType == CURRENT ? "C" :
+                                                (iType == CREDITCARD ? "D" :
+                                                        (iType == ASSETS ? "A" :
+                                                                (iType == INVESTMENT ? "I" :
+                                                                        (iType == WALLET ? "W" :
+                                                                                (iType == LOAN ? "L" :
+                                                                                        (iType == SAVING ? "S" :
+                                                                                                "O"))))))));
     return err;
 }
 
 SKGAccountObject::AccountType SKGAccountObject::getType() const
 {
     QString typeString = getAttribute("t_type");
-    return (typeString == "C" ? CURRENT : (typeString == "D" ? CREDITCARD : (typeString == "A" ? ASSETS : (typeString == "I" ? INVESTMENT : (typeString == "W" ? (typeString == "L" ? LOAN : OTHER) : OTHER)))));
+    return (typeString == "C" ? CURRENT :
+            (typeString == "D" ? CREDITCARD :
+             (typeString == "A" ? ASSETS :
+              (typeString == "I" ? INVESTMENT :
+               (typeString == "W" ? WALLET :
+                (typeString == "L" ? LOAN :
+                 (typeString == "S" ? SAVING : OTHER)))))));
 }
 
 SKGError SKGAccountObject::setClosed(bool iClosed)
