@@ -65,7 +65,8 @@ public:
                       ASSETS,    /**< to define a assets account */
                       OTHER,     /**< other kind of account */
                       WALLET,    /**< to define a wallet account */
-                      LOAN       /**< to define a loan account */
+                      LOAN,       /**< to define a loan account */
+                      SAVING       /**< to define a saving account */
                      };
 
     /**
