@@ -174,11 +174,12 @@ public Q_SLOTS:
     virtual QVariantList getBudget(const QString& iMonth);
 
     /**
-     * Get 5 main category report
+     * Get main categorys report
      * @param iMonth the month
+     * @param iNb number of categories
      * @return the report
      */
-    virtual QVariantList get5MainCategories(const QString& iMonth);
+    virtual QVariantList getMainCategories(const QString& iMonth, int iNb = 5);
 
     /**
      * Get 5 main variation of categories report
