@@ -24,6 +24,7 @@
 #include "skgerror.h"
 #include "skgreport.h"
 #include "skgbankmodeler_export.h"
+#include "skgunitobject.h"
 
 #include <QVariant>
 
@@ -44,11 +45,26 @@ class SKGBANKMODELER_EXPORT SKGReportBank : public SKGReport
      */
     Q_PROPERTY(QVariantList unit_table READ getUnitTable)
 
+    /**
+     * The portfolio
+     */
+    Q_PROPERTY(QVariantList portfolio READ getPortfolio)
+
     /**
      * The account table
      */
     Q_PROPERTY(QVariantList account_table READ getAccountTable)
 
+    /**
+     * The bank table
+     */
+    Q_PROPERTY(QVariantList bank_table READ getBankTable)
+
+    /**
+     * The scheduled operations
+     */
+    Q_PROPERTY(QVariantList scheduled_operations READ getScheduledOperations)
+
     /**
      * The main categories of the month
      */
@@ -69,16 +85,11 @@ class SKGBANKMODELER_EXPORT SKGReportBank : public SKGReport
      */
     Q_PROPERTY(QStringList categories_variations READ get5MainCategoriesVariation)
 
-    /**
-     * The main nls strings
-     */
-    Q_PROPERTY(QStringList titles READ getTitles)
-
 public:
     /**
      * Default Constructor
      */
-    SKGReportBank(SKGDocument* iDocument);
+    explicit SKGReportBank(SKGDocument* iDocument);
 
     /**
      * Default Destructor
@@ -97,12 +108,30 @@ public:
      */
     virtual QVariantList getUnitTable();
 
+    /**
+     * Get the portfolio
+     * @return the portfolio
+     */
+    virtual QVariantList getPortfolio();
+
     /**
      * Get the account table
      * @return the account table
      */
     virtual QVariantList getAccountTable();
 
+    /**
+     * Get the bank table
+     * @return the bank table
+     */
+    virtual QVariantList getBankTable();
+
+    /**
+     * Get the scheduled operations
+     * @return the scheduled operations
+     */
+    virtual QVariantList getScheduledOperations();
+
     /**
      * Get the main categories of the month
      * @return the main categories of the month
@@ -121,12 +150,6 @@ public:
      */
     virtual QStringList get5MainCategoriesVariation();
 
-    /**
-     * Get the main titles
-     * @return the main titles
-     */
-    virtual QStringList getTitles();
-
     /**
      * Get the income versus expenditure
      * @return the income versus expenditure
@@ -134,10 +157,10 @@ public:
     virtual QVariantList getIncomeVsExpenditure();
 
     /**
-     * Get advices
-     * @return the advices
+     * Get advice
+     * @return the advice
      */
-    virtual QVariant getAdvices();
+    virtual QVariant getAdvice();
 
 protected:
     /**
@@ -148,6 +171,14 @@ protected:
 
 private:
     Q_DISABLE_COPY(SKGReportBank);
+
+    typedef struct {
+        SKGUnitObject unit;
+        double initalAmount;
+        double purchaseAmount;
+        double currentAmount;
+        double quantity;
+    } unitValues;
 };
 
 #endif // SKGREPORTBANK_H
