@@ -664,15 +664,15 @@ SKGError SKGUnitObject::addSource(const QString& iNewSource)
             out << "mode=CSV or HTML" << endl << endl;
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
-                                "The regular expression for the price (see http://doc.qt.nokia.com/latest/qregexp.html)") << endl;
+                                "The regular expression for the price (see %1)", "http://doc.qt.nokia.com/latest/qregexp.html") << endl;
             out << "price=" << endl << endl;
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
-                                "The regular expression for the date (see http://doc.qt.nokia.com/latest/qregexp.html)") << endl;
+                                "The regular expression for the date (see %1)", "http://doc.qt.nokia.com/latest/qregexp.html") << endl;
             out << "date=" << endl << endl;
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
-                                "The format of the date (see http://doc.qt.nokia.com/latest/qdate.html#fromString-2)") << endl;
+                                "The format of the date (see %1)", "http://qt-project.org/doc/qt-5.0/qdate.html#fromString") << endl;
             out << "dateformat=yyyy-MM-dd" << endl;
 
             //Close file
@@ -1155,6 +1155,49 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
     return err;
 }
 
+SKGError SKGUnitObject::openURL()
+{
+    SKGError err;
+    SKGTRACEINRC(10, "SKGUnitObject::openURL", err);
+
+    QString url;
+    QString unitname = getName();
+    QString code = getInternetCode();
+    code.remove(" /");
+    QString source = getDownloadSource();
+    if (!code.isEmpty()) {
+        if (code.startsWith(QLatin1String("="))) {
+            //MODE FORMULAR
+
+        } else if (source.isEmpty() || source == i18nc("Native download source (Yahoo)", "Yahoo")) {
+            //NATIVE MODE
+            url = "http://ichart.finance.yahoo.com/table.csv?s=" % code % "&ignore=.csv";
+        } else {
+            //ALTERNATIVE MODE
+            QString fileName = KStandardDirs().findResource("data", "skrooge/quotes/" % source % ".txt");
+            if (fileName.isEmpty()) {
+                err = SKGError(ERR_FAIL, i18nc("Error message", "Source of download %1 is not installed.", source));
+            } else {
+                //Read source file
+                QHash< QString, QString > properties;
+                err = SKGServices::readPropertyFile(fileName, properties);
+
+                if (!err) {
+                    url = properties["url"].replace("%1", code);
+                }
+            }
+        }
+    }
+
+    if (err) {
+        err.addError(ERR_FAIL, i18nc("Error message", "Impossible to open unit %1 with Internet code %2.", unitname, code));
+    } else {
+        QDesktopServices::openUrl(QUrl(url));
+    }
+
+    return err;
+}
+
 SKGError SKGUnitObject::getOperations(SKGObjectBase::SKGListSKGObjectBase& oOperations) const
 {
     SKGError err = getDocument()->getObjects("v_operation",
