@@ -276,6 +276,14 @@ public:
      */
     virtual SKGError downloadUnitValue(UnitDownloadMode iMode = LAST, int iNbMaxValues = 50, bool iAdditionalInfo = false);
 
+
+    /**
+     * Open the URL where the values are downloaded
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError openURL();
+
     /**
      * Get the list of sources for the download
      * @return the list of sources
