@@ -63,7 +63,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGCalculatorEdit(QWidget* parent = 0);
+    explicit SKGCalculatorEdit(QWidget* parent = 0);
 
     /**
      * Default Destructor
@@ -89,7 +89,6 @@ public:
      */
     virtual double value();
 
-
     /**
      * Set the value
      * @param iValue the value
