@@ -23,7 +23,7 @@
  */
 
 #include "skgbasegui_export.h"
-#include "kdateedit.h"
+#include <kdateedit.h>
 
 /**
  * This file is a tab widget used by plugins
