@@ -46,7 +46,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGFilteredTableView(QWidget* parent = 0);
+    explicit SKGFilteredTableView(QWidget* parent = 0);
 
     /**
      * Default Destructor
