@@ -55,7 +55,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGGraphicsView(QWidget* parent = 0);
+    explicit SKGGraphicsView(QWidget* parent = 0);
 
     /**
      * Default Destructor
