@@ -113,7 +113,7 @@ bool SKGInterfacePlugin::isEnabled() const
     return true;
 }
 
-SKGAdviceList SKGInterfacePlugin::advices() const
+SKGAdviceList SKGInterfacePlugin::advice() const
 {
     SKGAdviceList output;
     return output;
