@@ -44,7 +44,7 @@ public:
      * Default constructor
      * @param parent the parent of the plugin
      */
-    SKGInterfacePlugin(QObject* parent = 0);
+    explicit SKGInterfacePlugin(QObject* parent = 0);
 
     /**
      * Default destructor
@@ -179,7 +179,7 @@ public:
      * The advice list of the plugin.
      * @return The advice list of the plugin
      */
-    virtual SKGAdviceList advices() const;
+    virtual SKGAdviceList advice() const;
 
     /**
      * Must be implemented to execute the automatic correction for the advice.
