@@ -28,7 +28,7 @@
 #include "skgtreeview.h"
 #include "skgwebview.h"
 
-#include <KTemporaryFile>
+#include <ktemporaryfile.h>
 #include <ktip.h>
 #include <ksplashscreen.h>
 #include <kconfigdialog.h>
@@ -57,16 +57,22 @@
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <ktoggleaction.h>
+#include <klineedit.h>
+#include <kencodingfiledialog.h>
+#include <ktabbar.h>
+
+#ifdef KActivities_FOUND
+#include <KActivities/ResourceInstance>
+#endif
 
 #include <QtGui/QProgressBar>
 #include <QtGui/QHeaderView>
 #include <QApplication>
 #include <QDir>
 #include <QResizeEvent>
-#include <klineedit.h>
+#include <qdesktopservices.h>
 #include <qtextcodec.h>
-#include <kencodingfiledialog.h>
-#include <ktabbar.h>
+
 
 bool SKGMainPanel::m_currentActionCanceled = false;
 SKGMainPanel* SKGMainPanel::m_mainPanel = NULL;
@@ -191,7 +197,9 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
                     }
                 }
             } else {
-                getDocument()->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()));
+                QString msg = i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2: %3", id, service->library(), loader.errorString());
+                getDocument()->sendMessage(msg);
+                SKGTRACEL(1) << "WARNING:" << msg << endl;
             }
         }
     }
@@ -468,6 +476,12 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
 
     connect(ui.kContextList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showMenu(QPoint)));
 
+#ifdef KActivities_FOUND
+    // Initialize kactivities resource instance
+    m_activityResourceInstance = new KActivities::ResourceInstance(window()->winId());
+    m_activityResourceInstance->setParent(this);
+#endif
+
     //Show menu bar and status bar
     menuBar()->show();
     statusBar()->show();
@@ -575,8 +589,10 @@ SKGInterfacePlugin* SKGMainPanel::getPluginByName(const QString& iName)
 {
     SKGInterfacePlugin* output = NULL;
     int nbplugin = m_pluginsList.count();
+    QString name = iName.toLower();
     for (int j = 0; !output && j < nbplugin; ++j) {
-        if (m_pluginsList[j]->objectName() == iName) {
+        QString namep = m_pluginsList[j]->objectName().toLower();
+        if (namep == name || namep.replace(' ', '_') == name) {
             output = m_pluginsList[j];
         }
     }
@@ -584,6 +600,11 @@ SKGInterfacePlugin* SKGMainPanel::getPluginByName(const QString& iName)
     return output;
 }
 
+KPluginInfo::List SKGMainPanel::getPlasmaApplets()
+{
+    return Plasma::Applet::listAppletInfo("", KCmdLineArgs::appName());
+}
+
 void SKGMainPanel::setupActions()
 {
     SKGTRACEIN(1, "SKGMainPanel::setupActions");
@@ -1060,28 +1081,28 @@ int SKGMainPanel::getNbSelectedObjects()
     return nb;
 }
 
-SKGAdviceList SKGMainPanel::getAdvices() const
+SKGAdviceList SKGMainPanel::getAdvice() const
 {
-    SKGTRACEIN(1, "SKGMainPanel::getAdvices");
-    //Get list of ignored advices
+    SKGTRACEIN(1, "SKGMainPanel::getAdvice");
+    //Get list of ignored advice
     QString currentMonth = QDate::currentDate().toString("yyyy-MM");
-    QStringList ignoredAdvices = getDocument()->getParameters("advices", "t_value='I' OR t_value='I_" % currentMonth % '\'');
+    QStringList ignoredAdvice = getDocument()->getParameters("advice", "t_value='I' OR t_value='I_" % currentMonth % '\'');
 
-    //Build the list of all advices by requesting all plugins
-    SKGAdviceList globalAdvicesList;
+    //Build the list of all advice by requesting all plugins
+    SKGAdviceList globalAdviceList;
     int index = 0;
     while (index >= 0) {
         SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
         if (plugin) {
-            foreach(const SKGAdvice & ad, plugin->advices()) {
-                if (!ignoredAdvices.contains(ad.getUUID()) && !ignoredAdvices.contains(SKGServices::splitCSVLine(ad.getUUID(), '|').at(0))) globalAdvicesList.push_back(ad);
+            foreach(const SKGAdvice & ad, plugin->advice()) {
+                if (!ignoredAdvice.contains(ad.getUUID()) && !ignoredAdvice.contains(SKGServices::splitCSVLine(ad.getUUID(), '|').at(0))) globalAdviceList.push_back(ad);
             }
         } else index = -2;
         ++index;
     }
-    qSort(globalAdvicesList.begin(), globalAdvicesList.end(), adviceLessThan);
+    qSort(globalAdviceList.begin(), globalAdviceList.end(), adviceLessThan);
 
-    return globalAdvicesList;
+    return globalAdviceList;
 }
 
 KConfigGroup SKGMainPanel::getMainConfigGroup()
@@ -1326,6 +1347,14 @@ void SKGMainPanel::refresh()
     if (getDocument()->isReadOnly()) modified += i18nc("Noun, indicate that current document is loaded in read only", " [read only]");
     QString fileName = getDocument()->getCurrentFileName();
     if (fileName.isEmpty()) fileName = i18nc("Noun, default name for a new document", "Untitled");
+    else {
+        if (fileName != m_fileName) {
+            m_fileName = fileName;
+#ifdef KActivities_FOUND
+            if (!m_fileName.isEmpty()) m_activityResourceInstance->setUri(m_fileName);
+#endif
+        }
+    }
     setWindowTitle(i18nc("Title of the main window", "%1%2 - %3", fileName, modified, KGlobal::activeComponent().componentName()));
 
     QApplication::restoreOverrideCursor();
@@ -1352,7 +1381,7 @@ SKGTabPage::SKGPageHistoryItem SKGMainPanel::currentPageHistoryItem() const
 
 SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const QString& parameters, const QString& title, const QString& iID, bool iSetCurrent)
 {
-    SKGTRACEIN(1, "SKGMainPanel::openPage");
+    SKGTRACEIN(1, "SKGMainPanel::openPage(plugin)");
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     bool previous = m_tabWidget->blockSignals(true);
     //If the current page is pin, then open new page
@@ -1461,12 +1490,64 @@ void SKGMainPanel::onBeforeOpenContext()
     m_middleClick = QApplication::mouseButtons() & Qt::MidButton;
 }
 
-void SKGMainPanel::openPage(int iPage, bool iNewPage)
+SKGTabPage* SKGMainPanel::openPage(const QUrl& iUrl, bool iNewPage)
 {
-    SKGTRACEIN(1, "SKGMainPanel::openPage");
+    KUrl url(iUrl);
+
+    if (url.protocol() == "skg") {
+        //Get plugin
+        SKGInterfacePlugin* plugin = getPluginByName(url.host());
+        if (plugin) {
+            //Open special page
+            SKGTabPage* w = plugin->getWidget();
+            if (w) {
+                //Create stata
+                QDomDocument doc("SKGML");
+                doc.setContent(getDocument()->getParameter(w->getDefaultStateAttribute()));
+                QDomElement root = doc.documentElement();
+                if (root.isNull()) {
+                    root = doc.createElement("parameters");
+                    doc.appendChild(root);
+                }
+                QMap< QString, QString > params = url.queryItems();
+
+                QStringList listKeys = params.keys();
+                foreach(const QString & k, listKeys) {
+                    QString value = KUrl::decode_string(params[k]);
+                    root.setAttribute(k, value);
+                }
+
+                //Open page
+                return openPage(plugin, iNewPage ? -1 : currentPageIndex(), doc.toString());
+            }
+        } else {
+            //Trigger action
+            QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction(url.host());
+            if (action) {
+                action->trigger();
+                return NULL;
+            }
+        }
+    } else {
+        QDesktopServices::openUrl(iUrl);
+        return NULL;
+    }
+    displayErrorMessage(SKGError(ERR_ABORT, i18nc("Error message", "Unknown plugin or action [%1] in url [%2]", url.host(), iUrl.toString())));
+
+    return NULL;
+}
+
+SKGTabPage* SKGMainPanel::openPage(const QString& iUrl, bool iNewPage)
+{
+    return openPage(QUrl(iUrl), iNewPage);
+}
+
+SKGTabPage* SKGMainPanel::openPage(int iPage, bool iNewPage)
+{
+    SKGTRACEIN(1, "SKGMainPanel::openPage(int)");
     SKGTRACEL(1) << "iPage=" << iPage << endl;
     int index = ui.kContextList->item(iPage)->data(12).toInt();
-    openPage(getPluginByIndex(index), iNewPage ? -1 : currentPageIndex());
+    return openPage(getPluginByIndex(index), iNewPage ? -1 : currentPageIndex());
 }
 
 void SKGMainPanel::onOpenContext(Qt::MouseButtons iMouse, Qt::KeyboardModifiers iKeyboard)
