@@ -340,7 +340,7 @@ void SKGObjectModelBase::refresh()
                         //Addition of a new group
                         currentGroup = att;
                         currentGoupId--;
-                        SKGObjectBase* group = new SKGObjectBase(NULL, "", currentGoupId);
+                        SKGObjectBase* group = new SKGObjectBase(m_document, "", currentGoupId);
                         group->setAttribute("t_title", currentGroup);
 
                         m_childParentRelations.insert(currentGoupId, 0);
@@ -885,13 +885,6 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
     return !err;
 }
 
-bool SKGObjectModelBase::canFetchMore(const QModelIndex& parent) const
-{
-    Q_UNUSED(parent);
-    _SKGTRACEIN(10, "SKGObjectModelBase::canFetchMore");
-    return false;
-}
-
 void SKGObjectModelBase::pageChanged()
 {
     if (m_isResetRealyNeeded) dataModified("", 0);
