@@ -181,13 +181,6 @@ public:
      */
     virtual SKGServices::AttributeType getAttributeType(int iIndex) const;
 
-    /**
-     * To know if the model can be fetched
-     * @param parent parent
-     * @return true of false
-     */
-    virtual bool canFetchMore(const QModelIndex& parent) const;
-
     /**
      * Set the table. Don't forget to do a reset after that.
      * @param iTable the table name
