@@ -71,7 +71,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGShow(QWidget* parent = 0);
+    explicit SKGShow(QWidget* parent = 0);
 
     /**
      * Default Destructor
