@@ -36,7 +36,7 @@ public:
     * Constructor
     * @param parent parent
     */
-    SKGTableWithGraphDesignerPlugin(QObject* parent = 0);
+    explicit SKGTableWithGraphDesignerPlugin(QObject* parent = 0);
 
     /**
      * To know if the component is a container
