@@ -54,7 +54,7 @@ public:
     /**
      * Default Constructor
      */
-    SKGTabPage(SKGDocument* iDocument);
+    explicit SKGTabPage(SKGDocument* iDocument);
 
     /**
      * Default Destructor
