@@ -75,7 +75,7 @@ void SKGTabWidget::onCurrentChanged()
     int nb = count();
     for (int i = 0; i < nb; ++i) {
         QWidget* w = widget(i);
-        QPushButton* save = static_cast<QPushButton*>(m_tabIndexSaveButton[w]);
+        QPushButton* save = qobject_cast<QPushButton*>(m_tabIndexSaveButton[w]);
         if (w && save) {
             save->setVisible(false);
 
