@@ -497,14 +497,6 @@ void SKGTreeView::setupHeaderMenu()
                 }
             }
             m_autoResizeDone = true;
-
-            //Span first column
-            if (m_proxyModel) {
-                int grouped_rows_count = m_proxyModel->rowCount(rootIndex());
-                for (int row = 0 ; row < grouped_rows_count ; row++) {
-                    setFirstColumnSpanned(row, rootIndex(), !m_groupby.isEmpty());
-                }
-            }
         }
         if (groupby) connect(groupby, SIGNAL(triggered(QAction*)), this, SLOT(groupByChanged(QAction*)));
         m_headerMenu->addSeparator();
@@ -951,7 +943,7 @@ void SKGTreeView::setTextResizable(bool resizable)
     m_textResizable = resizable;
 }
 
-SKGStringListList SKGTreeView::getTable()
+SKGStringListList SKGTreeView::getTable() const
 {
     //Build table
     SKGStringListList table;
@@ -966,21 +958,42 @@ SKGStringListList SKGTreeView::getTable()
         table.append(cols);
 
         //Get content
-        int nb2 = m_model->rowCount();
-        for (int i = 0; i < nb2; ++i) {
-            QStringList row;
-            for (int j = 0; j < nb; j++) {
-                //We have to check the type for 214849
-                SKGServices::AttributeType type = m_model->getAttributeType(j);
-                QString display = m_model->data(m_model->index(i, j), type == SKGServices::FLOAT ?  Qt::DisplayRole : Qt::UserRole).toString();
-                row.append(display);
-            }
-            table.append(row);
-        }
+        table.append(getTableContent());
     }
     return table;
 }
 
+SKGStringListList SKGTreeView::getTableContent(const QModelIndex& iIndex) const
+{
+    //Build table
+    SKGStringListList table;
+
+    int nb = m_model->columnCount();
+    int nb2 = m_model->rowCount(iIndex);
+    for (int i = 0; i < nb2; ++i) {
+        QStringList row;
+        for (int j = 0; j < nb; j++) {
+            //We have to check the type for 214849
+            QModelIndex idx = m_model->index(i, j, iIndex);
+
+            SKGServices::AttributeType type = m_model->getAttributeType(j);
+            QString display = m_model->data(idx, type == SKGServices::FLOAT || m_model->getObject(idx).getTable().isEmpty() ?  Qt::DisplayRole : Qt::UserRole).toString();
+            if (display.isEmpty()) m_model->data(idx, Qt::DisplayRole).toString();
+            row.append(display);
+        }
+
+        table.append(row);
+
+        QModelIndex idx0 = m_model->index(i, 0, iIndex);
+        if (m_model->hasChildren(idx0)) {
+            table.append(getTableContent(idx0));
+        }
+    }
+
+    return table;
+}
+
+
 void SKGTreeView::onExport()
 {
     _SKGTRACEIN(10, "SKGTreeView::onExport");
@@ -1026,17 +1039,20 @@ void SKGTreeView::onExport()
             painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
             painter.setWindow(image.rect());
             painter.drawImage(0, 0, image);
+            painter.end();
         }
     } else if (extension == "SVG") {
         QSvgGenerator generator;
         generator.setFileName(fileName);
-        generator.setSize(QSize(200, 200));
-        generator.setViewBox(QRect(0, 0, 200, 200));
         generator.setTitle(i18nc("Title of the content SVG export", "Skrooge SVG export"));
         generator.setDescription(i18nc("Description of the content SVG export", "A SVG drawing created by the Skrooge."));
 
         QPainter painter(&generator);
-        this->render(&painter);
+        QWidget* w = this->viewport();
+        w->render(&painter);
+        generator.setSize(QSize(w->widthMM(), w->heightMM()));
+        generator.setViewBox(QRect(0, 0, w->widthMM(), w->heightMM()));
+
         painter.end();
     } else {
         //Write file
