@@ -61,7 +61,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGTreeView(QWidget* parent = 0);
+    explicit SKGTreeView(QWidget* parent = 0);
 
     /**
      * Default Destructor
