@@ -36,7 +36,7 @@ public:
      * Constructor
      * @param parent parent
      */
-    SKGTreeViewDesignerPlugin(QObject* parent = 0);
+    explicit SKGTreeViewDesignerPlugin(QObject* parent = 0);
 
     /**
      * To know if the component is a container
