@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,6 +20,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgwidget.h"
+#include "skgtreeview.h"
 #include "skgtraces.h"
 
 #include <QtGui/QWidget>
@@ -36,7 +37,7 @@ SKGWidget::~SKGWidget()
     m_document = NULL;
 }
 
-SKGDocument * SKGWidget::getDocument() const
+SKGDocument* SKGWidget::getDocument() const
 {
     return m_document;
 }
@@ -58,8 +59,40 @@ void SKGWidget::setState(const QString& /*iState*/)
 QWidget* SKGWidget::getDragWidget()
 {
     QWidget* w = this->findChild<QWidget*>("kGroup");
-    if(!w) w = this;
+    if (!w) w = this;
     return w;
 }
+SKGObjectBase::SKGListSKGObjectBase SKGWidget::getSelectedObjects()
+{
+    SKGObjectBase::SKGListSKGObjectBase selection;
+    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(mainWidget());
+    if (treeView) selection = treeView->getSelectedObjects();
+
+    return selection;
+}
+
+SKGObjectBase SKGWidget::getFirstSelectedObject()
+{
+    SKGObjectBase first;
+    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(mainWidget());
+    if (treeView) first = treeView->getFirstSelectedObject();
+
+    return first;
+}
+
+int SKGWidget::getNbSelectedObjects()
+{
+    int output = 0;
+    SKGTreeView* treeView = qobject_cast<SKGTreeView*>(mainWidget());
+    if (treeView) output = treeView->getNbSelectedObjects();
+    else output = getSelectedObjects().count();
+
+    return output;
+}
+
+QWidget* SKGWidget::mainWidget() const
+{
+    return (QWidget*) this;
+}
 
 #include "skgwidget.moc"
