@@ -54,7 +54,7 @@ public:
      * Default Constructor
      * @param parent the parent
      */
-    SKGWidgetSelector(QWidget* parent = 0);
+    explicit SKGWidgetSelector(QWidget* parent = 0);
 
     /**
      * Default Destructor
