@@ -36,7 +36,7 @@ SKGZoomSelector::SKGZoomSelector(QWidget* parent)
 
     //Init timer
     m_timer.setSingleShot(true);
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onZoomChanged()));
+    connect(&m_timer, SIGNAL(timeout()), this, SLOT(onZoomChanged()), Qt::QueuedConnection);
 }
 
 SKGZoomSelector::~SKGZoomSelector()
