@@ -330,10 +330,11 @@ public Q_SLOTS:
      * @param iName the file name to load.
      * @param iPassword the password of the SKGDocument.
      * @param iRestoreTmpFile restore the temporary file if existing.
+     * @param iForceReadOnly force the read only mode.
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError load(const QString& iName, const QString& iPassword = "", bool iRestoreTmpFile = false);
+    virtual SKGError load(const QString& iName, const QString& iPassword = "", bool iRestoreTmpFile = false, bool iForceReadOnly = false);
 
     /**
      * To know if the current document has been modified or not.
@@ -576,9 +577,10 @@ public Q_SLOTS:
     /**
      * Get the temporary file for a file
      * @param iFileName the file
+     * @param iForceReadOnly force the read only mode
      * @return the temporary file
      */
-    static QString getTemporaryFile(const QString iFileName);
+    static QString getTemporaryFile(const QString iFileName, bool iForceReadOnly = false);
 
     /**
      * Get the temporary file for a document
@@ -689,6 +691,15 @@ public Q_SLOTS:
      */
     virtual SKGError executeSqliteOrders(const QStringList& iSqlOrders) const;
 
+    /**
+     * Execute a sqlite order
+     * @param iSqlOrder the sql order
+     * @param iBind the binded variables and values
+     * @param iLastId to retrieve the id of the last created object
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError executeSqliteOrder(const QString& iSqlOrder, const QMap<QString, QVariant>& iBind, int* iLastId = NULL) const;
     /**
      * Execute a sqlite order
      * @param iSqlOrder the sql order
