@@ -60,7 +60,7 @@ public:
     /**
     * Constructor
     */
-    SKGError();
+    explicit SKGError();
 
     /**
     * Copy constructor
