@@ -737,24 +737,24 @@ SKGError SKGServices::copySqliteDatabaseToJson(QSqlDatabase* iDb, QString& oDocu
                 for (int j = 1; !err && j < nbRows; ++j) { //Forget title
                     QStringList values = listRows.at(j);
 
-                    oDocument += "{";
+                    oDocument += '{';
                     int nbVals = values.count();
                     for (int k = 0; k < nbVals; ++k) {
-		        QString v=values.at(k);
-		        v=v.replace("\\","\\\\");
-		        v=v.replace("\t","\\\t");
-		        v=v.replace("\r","\\\r");
-		        v=v.replace("\n","\\\n");
-		        v=v.replace("\f","\\\f");
-		        v=v.replace("\b","\\\b");
-		        v=v.replace("/","\\/");
-		        v=v.replace("\"","\\\"");
-                        oDocument += "\"" % titles.at(k) % "\":\"" % v % "\"";
-                        if (k < nbVals - 1) oDocument += ",";
+                        QString v = values.at(k);
+                        v = v.replace("\\", "\\\\");
+                        v = v.replace('\t', "\\\t");
+                        v = v.replace('\r', "\\\r");
+                        v = v.replace('\n', "\\\n");
+                        v = v.replace('\f', "\\\f");
+                        v = v.replace('\b', "\\\b");
+                        v = v.replace('/', "\\/");
+                        v = v.replace('"', "\\\"");
+                        oDocument += '"' % titles.at(k) % "\":\"" % v % '"';
+                        if (k < nbVals - 1) oDocument += ',';
                     }
-                    oDocument += "}";
-                    if (j < nbRows - 1) oDocument += ",";
-                    oDocument += "\n";
+                    oDocument += '}';
+                    if (j < nbRows - 1) oDocument += ',';
+                    oDocument += '\n';
                 }
             }
             oDocument += "]\n";
@@ -897,7 +897,7 @@ SKGError SKGServices::executeSqliteOrders(QSqlDatabase* iDb, const QStringList&
     return err;
 }
 
-SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, int* iLastId)
+SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, const QMap<QString, QVariant>& iBind, int* iLastId)
 {
     SKGError err;
     _SKGTRACEINRC(10, "SKGServices::executeSqliteOrder(QSqlDatabase)", err);
@@ -907,10 +907,22 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
         err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
     } else {
         QSqlQuery query(QString(), *iDb);
+        query.setForwardOnly(true);
+
         double elapse = 0;
         if (SKGServices::SKGSqlTraces != -1)  elapse = SKGServices::getMicroTime();
 
-        if (!query.exec(iSqlOrder)) {
+        //Prepare sql order
+        bool prep = query.prepare(iSqlOrder);
+
+        //Bind values
+        QMapIterator<QString, QVariant> i(iBind);
+        while (i.hasNext()) {
+            i.next();
+            query.bindValue(i.key(), i.value());
+        }
+
+        if (!prep || !query.exec()) {
             QSqlError sqlError = query.lastError();
             if (sqlError.number() != 19 /*SQLITE_CONSTRAINT*/) {
                 SKGTRACE << "WARNING: " << iSqlOrder << endl;
@@ -932,6 +944,11 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
     return err;
 }
 
+SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, int* iLastId)
+{
+    return executeSqliteOrder(iDb, iSqlOrder, QMap< QString, QVariant >(), iLastId);
+}
+
 SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QTextStream* oStream, SKGServices::DumpMode iMode)
 {
     SKGError err;
@@ -993,6 +1010,7 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
     if (iDb == NULL) err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
     else {
         QSqlQuery query(QString(), *iDb);
+        query.setForwardOnly(true);
         double elapse = 0;
         if (SKGServices::SKGSqlTraces != -1)  elapse = SKGServices::getMicroTime();
 
